| lapply_pb | R Documentation |
This function is a wrapper of lapply function that allows the drawing of a progress bar to assess the speed of the process.
lapply_pb (X, FUN, ...)
X |
a vector (atomic or list) or an expression object. See see |
FUN |
the function to be applied to each element of X: see |
... |
passes another arguments to the typical lapply function. |
No major details
Performs lapply drawing a progress bar
the same result than using lapply
See see lapply
l <- sapply(1:200, function(x) list(rnorm(1000)))
lapply_pb(l, mean)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.