| threshs | R Documentation |
This function takes data contained in a list with 2 elements, the first containing the position in base pairs and the heights of the positions and given a panel finds the best minimum threshold by creating a confidence interval in order to get only the real peaks. Implemented internally of auto,score and score.easy function.
threshs(my.plant, min.thre=200, panel, ci=1.9)
my.plant |
List with 2 elements; the position in base pairs and the heights associated with them |
min.thre |
Starting threshold to find the peaks and refine the search |
panel |
Two scalar values indicatin the interval where the peaks should be found |
ci |
Scalar value indicating the number of standard errors to be used when creating the confidence interval for ssr calling |
No major details.
If arguments are correctly specified the function returns a list containing
A scalar value indicating the new threshold to be used when calling the real peaks
Robert J. Henry. 2013. Molecular Markers in Plants. Wiley-Blackwell. ISBN 978-0-470-95951-0.
Ben Hui Liu. 1998. Statistical Genomics. CRC Press LLC. ISBN 0-8493-3166-8.
data(my.plants)
# implemented internally of auto,score and score.easy function
# threshs(my.plant, min.thre=200, panel=(260,290), ci=1.9)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.